@@ -2,8 +2,7 @@
 from graphviz import Digraph
 from ..Edge.BaseEdge import BaseEdge
 from ..Victor.BaseVictor import BaseVictor
-
-from Victor.WorkflowVictor import WorkflowVictor
+from ..Victor.WorkflowVictor import WorkflowVictor
 
 class GraphTool:
     shape = {"branch":"diamond","container":"box","start":"ellipse","end":"ellipse"}
