@@ -1,4 +1,4 @@
-from Victor.BaseVictor import BaseVictor
+from ..Victor.BaseVictor import BaseVictor
 
 class EndVictor(BaseVictor):
 
